################################################################
:mod:`.annotations <highcharts_core.options.annotations>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  animation
  control_point_options
  events
  label_options
  points
  shape_options

--------------

.. module:: highcharts_core.options.annotations

****************************************************************************************
class: :class:`Annotation <highcharts_core.options.annotations.Annotation>`
****************************************************************************************

.. autoclass:: Annotation
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: Annotation
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

-----------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.annotations <highcharts_core.options.annotations>`
    - :class:`Annotation <highcharts_core.options.annotations.Annotation>`
  * - :mod:`.options.annotations.animation <highcharts_core.options.annotations.animation>`
    - :class:`AnnotationAnimation <highcharts_core.options.annotations.animation.AnnotationAnimation>`
  * - :mod:`.options.annotations.control_point_options <highcharts_core.options.annotations.control_point_options>`
    - :class:`AnnotationControlPointOption <highcharts_core.options.annotations.control_point_options.AnnotationControlPointOption>`
  * - :mod:`.options.annotations.events <highcharts_core.options.annotations.events>`
    - :class:`AnnotationEvent <highcharts_core.options.annotations.events.AnnotationEvent>`
  * - :mod:`.options.annotations.label_options <highcharts_core.options.annotations.label_options>`
    - :class:`AnnotationLabel <highcharts_core.options.annotations.label_options.AnnotationLabel>`
      :class:`AnnotationLabelOptionAccessibility <highcharts_core.options.annotations.label_options.AnnotationLabelOptionAccessibility>`
      :class:`LabelOptions <highcharts_core.options.annotations.label_options.LabelOptions>`
  * - :mod:`.options.annotations.options.annotations.points <highcharts_core.options.annotations.points>`
    - :class:`AnnotationPoint <highcharts_core.options.annotations.points.AnnotationPoint>`
  * - :mod:`.options.annotations.shape_options <highcharts_core.options.annotations.shape_options>`
    - :class:`AnnotationShape <highcharts_core.options.annotations.shape_options.AnnotationShape>`
      :class:`ShapeOptions <highcharts_core.options.annotations.shape_options.ShapeOptions>`
